# Wanga
[![License: MIT](https://img.shields.io/badge/license-MIT-C06524)](https://github.com/norpadon/wanga/blob/main/LICENSE)
[![tests](https://github.com/norpadon/wanga/actions/workflows/tests.yaml/badge.svg)](https://github.com/norpadon/wanga/actions/workflows/tests.yaml)
[![lint](https://github.com/norpadon/wanga/actions/workflows/lint.yaml/badge.svg)](https://github.com/norpadon/wanga/actions/workflows/lint.yaml)
[![docs](https://github.com/norpadon/wanga/actions/workflows/docs.yaml/badge.svg)](https://norpadon.github.io/wanga/)

